package com.qianhe.service;

import java.util.List;
import com.qianhe.domain.BzscZczscZb;

/**
 * 标准手册-注采站管理手册-主Service接口
 * 
 * @author qianhe
 * @date 2024-09-11
 */
public interface IBzscZczscZbService 
{
    /**
     * 查询标准手册-注采站管理手册-主
     * 
     * @param ID 标准手册-注采站管理手册-主主键
     * @return 标准手册-注采站管理手册-主
     */
    public BzscZczscZb selectBzscZczscZbByID(Long ID);

    /**
     * 查询标准手册-注采站管理手册-主列表
     * 
     * @param bzscZczscZb 标准手册-注采站管理手册-主
     * @return 标准手册-注采站管理手册-主集合
     */
    public List<BzscZczscZb> selectBzscZczscZbList(BzscZczscZb bzscZczscZb);

    /**
     * 新增标准手册-注采站管理手册-主
     * 
     * @param bzscZczscZb 标准手册-注采站管理手册-主
     * @return 结果
     */
    public int insertBzscZczscZb(BzscZczscZb bzscZczscZb);

    /**
     * 修改标准手册-注采站管理手册-主
     * 
     * @param bzscZczscZb 标准手册-注采站管理手册-主
     * @return 结果
     */
    public int updateBzscZczscZb(BzscZczscZb bzscZczscZb);

    /**
     * 批量删除标准手册-注采站管理手册-主
     * 
     * @param IDs 需要删除的标准手册-注采站管理手册-主主键集合
     * @return 结果
     */
    public int deleteBzscZczscZbByIDs(Long[] IDs);

    /**
     * 删除标准手册-注采站管理手册-主信息
     * 
     * @param ID 标准手册-注采站管理手册-主主键
     * @return 结果
     */
    public int deleteBzscZczscZbByID(Long ID);
}
